diff --git a/android/hal-audio.c b/android/hal-audio.c
index d37d6098c0..bd19b7299b 100644
--- a/android/hal-audio.c
+++ b/android/hal-audio.c
@@ -1237,7 +1237,7 @@ static int audio_set_voice_volume(struct audio_hw_device *dev, float volume)
 	return -ENOSYS;
 }
 
-static int audio_set_master_volume(struct audio_hw_device *dev, float volume)
+static int audio_set_main_volume(struct audio_hw_device *dev, float volume)
 {
 	DBG("");
 	return -ENOSYS;
@@ -1346,13 +1346,13 @@ static int audio_dump(const audio_hw_device_t *device, int fd)
 }
 
 #if ANDROID_VERSION >= PLATFORM_VER(5, 0, 0)
-static int set_master_mute(struct audio_hw_device *dev, bool mute)
+static int set_main_mute(struct audio_hw_device *dev, bool mute)
 {
 	DBG("");
 	return -ENOSYS;
 }
 
-static int get_master_mute(struct audio_hw_device *dev, bool *mute)
+static int get_main_mute(struct audio_hw_device *dev, bool *mute)
 {
 	DBG("");
 	return -ENOSYS;
@@ -1574,7 +1574,7 @@ static int audio_open(const hw_module_t *module, const char *name,
 
 	a2dp_dev->dev.init_check = audio_init_check;
 	a2dp_dev->dev.set_voice_volume = audio_set_voice_volume;
-	a2dp_dev->dev.set_master_volume = audio_set_master_volume;
+	a2dp_dev->dev.set_main_volume = audio_set_main_volume;
 	a2dp_dev->dev.set_mode = audio_set_mode;
 	a2dp_dev->dev.set_mic_mute = audio_set_mic_mute;
 	a2dp_dev->dev.get_mic_mute = audio_get_mic_mute;
@@ -1587,8 +1587,8 @@ static int audio_open(const hw_module_t *module, const char *name,
 	a2dp_dev->dev.close_input_stream = audio_close_input_stream;
 	a2dp_dev->dev.dump = audio_dump;
 #if ANDROID_VERSION >= PLATFORM_VER(5, 0, 0)
-	a2dp_dev->dev.set_master_mute = set_master_mute;
-	a2dp_dev->dev.get_master_mute = get_master_mute;
+	a2dp_dev->dev.set_main_mute = set_main_mute;
+	a2dp_dev->dev.get_main_mute = get_main_mute;
 	a2dp_dev->dev.create_audio_patch = create_audio_patch;
 	a2dp_dev->dev.release_audio_patch = release_audio_patch;
 	a2dp_dev->dev.get_audio_port = get_audio_port;
diff --git a/android/hal-sco.c b/android/hal-sco.c
index d7c08a68b8..15400d5cfe 100644
--- a/android/hal-sco.c
+++ b/android/hal-sco.c
@@ -840,7 +840,7 @@ static int sco_set_voice_volume(struct audio_hw_device *dev, float volume)
 	return 0;
 }
 
-static int sco_set_master_volume(struct audio_hw_device *dev, float volume)
+static int sco_set_main_volume(struct audio_hw_device *dev, float volume)
 {
 	DBG("%f", volume);
 
@@ -1292,13 +1292,13 @@ static int sco_dump(const audio_hw_device_t *device, int fd)
 }
 
 #if ANDROID_VERSION >= PLATFORM_VER(5, 0, 0)
-static int set_master_mute(struct audio_hw_device *dev, bool mute)
+static int set_main_mute(struct audio_hw_device *dev, bool mute)
 {
 	DBG("");
 	return -ENOSYS;
 }
 
-static int get_master_mute(struct audio_hw_device *dev, bool *mute)
+static int get_main_mute(struct audio_hw_device *dev, bool *mute)
 {
 	DBG("");
 	return -ENOSYS;
@@ -1477,7 +1477,7 @@ static int sco_open(const hw_module_t *module, const char *name,
 
 	dev->dev.init_check = sco_init_check;
 	dev->dev.set_voice_volume = sco_set_voice_volume;
-	dev->dev.set_master_volume = sco_set_master_volume;
+	dev->dev.set_main_volume = sco_set_main_volume;
 	dev->dev.set_mode = sco_set_mode;
 	dev->dev.set_mic_mute = sco_set_mic_mute;
 	dev->dev.get_mic_mute = sco_get_mic_mute;
@@ -1490,8 +1490,8 @@ static int sco_open(const hw_module_t *module, const char *name,
 	dev->dev.close_input_stream = sco_close_input_stream;
 	dev->dev.dump = sco_dump;
 #if ANDROID_VERSION >= PLATFORM_VER(5, 0, 0)
-	dev->dev.set_master_mute = set_master_mute;
-	dev->dev.get_master_mute = get_master_mute;
+	dev->dev.set_main_mute = set_main_mute;
+	dev->dev.get_main_mute = get_main_mute;
 	dev->dev.create_audio_patch = create_audio_patch;
 	dev->dev.release_audio_patch = release_audio_patch;
 	dev->dev.get_audio_port = get_audio_port;
diff --git a/android/hardware/audio.h b/android/hardware/audio.h
index b612b9d11c..874aec1264 100644
--- a/android/hardware/audio.h
+++ b/android/hardware/audio.h
@@ -514,16 +514,16 @@ struct audio_hw_device {
      * Range between 0.0 and 1.0. If any value other than 0 is returned,
      * the software mixer will emulate this capability.
      */
-    int (*set_master_volume)(struct audio_hw_device *dev, float volume);
+    int (*set_main_volume)(struct audio_hw_device *dev, float volume);
 
     /**
      * Get the current master volume value for the HAL, if the HAL supports
      * master volume control.  AudioFlinger will query this value from the
      * primary audio HAL when the service starts and use the value for setting
      * the initial master volume across all HALs.  HALs which do not support
      * this method may leave it set to NULL.
      */
-    int (*get_master_volume)(struct audio_hw_device *dev, float *volume);
+    int (*get_main_volume)(struct audio_hw_device *dev, float *volume);
 
     /**
      * set_mode is called when the audio mode changes. AUDIO_MODE_NORMAL mode
@@ -592,16 +592,16 @@ struct audio_hw_device {
      * set the audio mute status for all audio activities.  If any value other
      * than 0 is returned, the software mixer will emulate this capability.
      */
-    int (*set_master_mute)(struct audio_hw_device *dev, bool mute);
+    int (*set_main_mute)(struct audio_hw_device *dev, bool mute);
 
     /**
      * Get the current master mute status for the HAL, if the HAL supports
      * master mute control.  AudioFlinger will query this value from the primary
      * audio HAL when the service starts and use the value for setting the
      * initial master mute across all HALs.  HALs which do not support this
      * method may leave it set to NULL.
      */
-    int (*get_master_mute)(struct audio_hw_device *dev, bool *mute);
+    int (*get_main_mute)(struct audio_hw_device *dev, bool *mute);
 
     /**
      * Routing control
@@ -514,16 +514,16 @@ struct audio_hw_device {
 
     /**
-     * Get the current master volume value for the HAL, if the HAL supports
-     * master volume control.  AudioFlinger will query this value from the
+     * Get the current main volume value for the HAL, if the HAL supports
+     * main volume control.  AudioFlinger will query this value from the
      * primary audio HAL when the service starts and use the value for setting
@@ -514,16 +514,16 @@ struct audio_hw_device {
      * primary audio HAL when the service starts and use the value for setting
-     * the initial master volume across all HALs.  HALs which do not support
+     * the initial main volume across all HALs.  HALs which do not support
      * this method may leave it set to NULL.
      */
@@ -592,16 +592,16 @@ struct audio_hw_device {
 
     /**
-     * Get the current master mute status for the HAL, if the HAL supports
-     * master mute control.  AudioFlinger will query this value from the primary
+     * Get the current main mute status for the HAL, if the HAL supports
+     * main mute control.  AudioFlinger will query this value from the primary
      * audio HAL when the service starts and use the value for setting the
@@ -592,16 +592,16 @@ struct audio_hw_device {
      * audio HAL when the service starts and use the value for setting the
-     * initial master mute across all HALs.  HALs which do not support this
+     * initial main mute across all HALs.  HALs which do not support this
      * method may leave it set to NULL.
      */
